@@ -20,9 +20,9 @@ from pprint import pprint
 
 from six.moves import http_client
 
-from ovirt_imageio_daemon import pki
+from ovirt_imageio_common import uhttp
 from ovirt_imageio_daemon import config
-from ovirt_imageio_daemon import uhttp
+from ovirt_imageio_daemon import pki
 
 log = logging.getLogger("test")
 
